intelmq.bots.collectors.file package — intelmq 2.3.3.alpha1 documentation

# intelmq.bots.collectors.file package

## Submodules

## intelmq.bots.collectors.file.collector_file module

File Collector Bot

Regularly checks a directory and reads files matching an extension from it It can delete the file if a delete switch was set. The bot creates on report per file.

Copyright (C) 2016 by Bundesamt für Sicherheit in der Informationstechnik Software engineering by Intevation GmbH

param path

  string

param postfix

  string

param delete_file

  boolean

param default

  False

`intelmq.bots.collectors.file.collector_file.` `BOT`

  alias of `intelmq.bots.collectors.file.collector_file.FileCollectorBot`

class `intelmq.bots.collectors.file.collector_file.` `FileCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  `init`()
  `process`()

## Module contents